weaviate.collections.batch package
==================================

.. automodule:: weaviate.collections.batch
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.collections.batch.batch module
---------------------------------------

.. automodule:: weaviate.collections.batch.batch
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.batch.grpc module
--------------------------------------

.. automodule:: weaviate.collections.batch.grpc
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.batch.rest module
--------------------------------------

.. automodule:: weaviate.collections.batch.rest
   :members:
   :undoc-members:
   :show-inheritance:
